@@ -3,8 +3,8 @@
 
 # (c) by Tels http://bloodgate.com 2004-2005
 
-# Takes text between <graph> </graph> tags, and runs it through
-# the external script "graphcnv", which generates an ASCII or HTML
+# Takes text between <graph> </graph> tags, and runs it through the
+# external script "graphcnv", which generates an ASCII, HTML or SVG
 # graph from it.
 
 $wgExtensionFunctions[] = "wfGraphExtension";
@@ -17,13 +17,19 @@ function wfGraphExtension() {
 
     $wgParser->setHook( "graph", "renderGraph" );
 }
+
+$wgExtensionCredits[parserhook][] = array(
+	'name' => 'graph extension',
+	'author' => 'Tels',
+	'url' => 'http://wwww.bloodgate.com/perl/graph/',
+);
  
 # The callback function for converting the input text to HTML output
 function renderGraph( $input ) {
     global $wgInputEncoding;
 
     if( !is_executable( "graph/graphcnv" ) ) {
-	return "<strong class='error'> <code>graph/graphcnv</code> is not executable </strong>";
+	return "<strong class='error'><code>graph/graphcnv</code> is not executable</strong>";
     }
 
     $cmd = "graph/graphcnv ".
@@ -32,7 +38,7 @@ function renderGraph( $input ) {
     $output = `$cmd`;
 
     if (strlen($output) == 0) {
-	return "<strong class='error'> Couldn't execute <code>graph/graphcnv</code> </strong>";
+	return "<strong class='error'>Couldn't execute <code>graph/graphcnv</code></strong>";
     }
 
     return $output;
